@@ -410,36 +410,48 @@ body <- dashboardBody(
                                        numericInput("par_min_clique_size", "Minimal cliques size", value = 3, min = 2, max = 10)
                               ),
                               introBox(data.step = 8, 
+                                       data.intro = "Check to align positive / negative poles before building the graphs. Generally, this you be done.",
+                                       awesomeCheckbox("par_align_poles", "Align pos./neg. poles", value = TRUE)
+                              ),
+                              introBox(data.step = 9, 
+                                       data.intro = "Check to prefix poles with (+) / (-) to indicate pole preference.",
+                                       awesomeCheckbox("par_valence_prefix", "(+/-) pole preference prefix", value = TRUE)
+                              ),
+                              introBox(data.step = 10, 
                                        data.intro = "Check to draw lines between related constructs.",
                                        awesomeCheckbox("par_show_edges", "Lines between related constructs", value = TRUE)
                               ),
-                              introBox(data.step = 9, 
+                              introBox(data.step = 11, 
                                        data.intro = "Check to indicate the direction of a construct relation (positive / negative) by a +/- sign.",
                                        awesomeCheckbox("par_indicate_direction", "Indicate relation by +/-", value = TRUE)
                               ),
-                              introBox(data.step = 10, 
+                              introBox(data.step = 12, 
                                        data.intro = "Check to colorize the direction of a construct relation (positive / negative) by red and green color.",
                                        awesomeCheckbox("par_colorize_direction", "Indicate relation by color", value = TRUE)
                               ),
                               
-                              introBox(data.step = 11, 
-                                       data.intro = "Check if you want to get a different color for each clique/cluster.",
+                              introBox(data.step = 13, 
+                                       data.intro = "Check to get a different color for each clique/cluster.",
                                        awesomeCheckbox("par_colorize_cliques", "Colorize clusters", value = TRUE)
                               ),
+                              introBox(data.step = 14, 
+                                       data.intro = "Set maximal no of characters of construct labels to avoid cluttering the plot.",
+                                       numericInput("par_label_max_length", "Max. length of construct labels", value = 100, min = -1, max = 100)
+                              ),
                               # introBox(data.step = 8, 
                               #          data.intro = "Whether to show full or abbreviated construct labels (C1, C2 etc.) in the output graphs.
                               #                        By default full labels are shown.",
                               #          awesomeCheckbox("par_abbr_labels", "Abbreviate construct labels", value = FALSE)
                               # ),
                               div(style = "display:inline-block; float:left; margin-right: 10px",
-                                introBox(data.step = 12, 
+                                introBox(data.step = 15, 
                                          data.intro = "Process the grid data and generate an Excel file containing 
                                                        the results for download.",
                                     actionButton("btn_process", label = "Process data")
                                  )
                               ),
                               div(style="display:inline-block; float:left",
-                                introBox(data.step = 13, 
+                                introBox(data.step = 16, 
                                          data.intro = "After the result file has been created, you can download it here.",
                                   disabled(
                                    downloadButton(outputId = "btn_download_excel", style = "minimal", class = "downloadBtn", label = "Download results")
